copysignf
产品支持情况
- Ascend 950PR/Ascend 950DT:支持
- Atlas A3 训练系列产品/Atlas A3 推理系列产品:不支持
- Atlas A2 训练系列产品/Atlas A2 推理系列产品:不支持
- Atlas 200I/500 A2 推理产品:不支持
- Atlas 推理系列产品AI Core:不支持
- Atlas 推理系列产品Vector Core:不支持
- Atlas 训练系列产品:不支持
功能说明
获取由第一个输入x的数值部分和第二个输入y的符号部分拼接得到的浮点数。

函数原型
C++
inline float copysignf(float x, float y)
参数说明
表1 参数说明
| 参数名 | 输入/输出 | 描述 |
|---|---|---|
| x | 输入 | 源操作数。 |
| y | 输入 | 源操作数。 |
返回值说明
- y>=0时,返回x的绝对值Abs(x)。
- y<0时,返回x绝对值的相反数,-Abs(x)。
- y=nan时,返回-Abs(x)。
- y=-inf时,返回-Abs(x)。
- y=inf时,返回Abs(x)。
约束说明
无
需要包含的头文件
使用该接口需要包含"simt_api/math_functions.h"头文件。
C++
#include "simt_api/math_functions.h"
调用示例
SIMT编程场景:
C++__global__ __launch_bounds__(256) void compute_copysignf(float *result, const float *x, const float *y, uint32_t count) { const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x; if (idx >= count) { return; } result[idx] = copysignf(x[idx], y[idx]); }SIMD与SIMT混合编程场景:
C++__simt_vf__ __launch_bounds__(256) inline void compute_copysignf_vf(__gm__ float *result, __gm__ const float *x, __gm__ const float *y, uint32_t count) { const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x; if (idx >= count) { return; } result[idx] = copysignf(x[idx], y[idx]); } __global__ __vector__ void run_copysignf(__gm__ float *result, __gm__ const float *x, __gm__ const float *y, uint32_t count) { asc_vf_call<compute_copysignf_vf>(dim3(256), result, x, y, count); }
输入输出示例如下:
Text
x:0.25, -0.75, 1.25, -1.75
y:1.5, 2.5, -3.5, -4.5
result: 0.25 0.75 -1.25 -1.75